Maspy
=====

Introduction
------------
Maspy is a Python library with the aim to provide simple, convenient and
versatile access to proteomics data of bottom up experiments. To achieve this
it features an internal data representation that facilitates comfortable use
of this data. Maspy is intended as a tool for researchers that allows the
combination of different software to generate customized and scriptable data
processing workflows and to enable interactive data analysis with Python.

Documentation
-------------
An introduction to the underlying concepts of maspy is available at
http://maspy.readthedocs.io

Workflow examples
-----------------
In order to show how to use maspy we are going to provide examples of simple
data analysis workflows.

Test files
----------
Test files can be downloaded from
https://github.com/hollenstein/maspy_testfiles

Installation
------------
For Windows users without Python we recommend installing the
`Anaconda <https://www.continuum.io/downloads>`_ Python package provided by
Continuum Analytics.

NOTE: The current release of maspy will soon be submitted to
`PyPi <https://pypi.python.org/>`_, which allows installation with PIP, as
described below:

For installing maspy and its dependencies we recommend using
`PIP <https://pip.pypa.io/en/stable/installing/>`_.

Installing maspy from the command line with PIP after the release:

```
pip install maspy
```

Compatibility
-------------
Maspy is developed and tested on Python 2.7 and 3.5.
Tested on Windows (7) and Linux (Debian 8).

License
-------
maspy is licensed under the `Apache License 2.0
<http://www.apache.org/licenses/LICENSE-2.0.txt>`_.

The project contains additional code and files licensed under different
licenses. For details refer to `LICENSE.txt
<https://github.com/hollenstein/maspy/blob/master/LICENSE.txt>`_.


Contributors
------------
David Hollenstein https://github.com/hollenstein

Jakob Hollenstein https://github.com/jkbjh
